@@ -10,19 +10,19 @@ compute_evpi <- function(x, wtp_thresholds) {
       ),
       by = ".key"
     ) %>% 
-    dplyr::group_by_(~ .ceac, ~ .index) %>% 
-    dplyr::mutate_(
-      .nmb = ~ .effect * .ceac - .cost,
-      .top_strategy = ~ .nmb == max(.nmb),
-      .top_strategy = ~ .top_strategy & cumsum(.top_strategy) == 1,
-      .top_choice = ~ .strategy_names == .strategy_choice
+    dplyr::group_by(.data$.ceac, .data$.index) %>% 
+    dplyr::mutate(
+      .nmb = .data$.effect * .data$.ceac - .data$.cost,
+      .top_strategy = .data$.nmb == max(.data$.nmb),
+      .top_strategy = .data$.top_strategy & cumsum(.data$.top_strategy) == 1,
+      .top_choice = .data$.strategy_names == .data$.strategy_choice
       # in case 2 nmb are identical, pick first
     ) %>% 
-    dplyr::summarise_(
-      .evpi = ~ .nmb[.top_strategy] - .nmb[.top_choice]
+    dplyr::summarise(
+      .evpi = .data$.nmb[.data$.top_strategy] - .data$.nmb[.data$.top_choice]
     ) %>% 
-    dplyr::summarise_(
-      .evpi = ~ mean(.evpi)
+    dplyr::summarise(
+      .evpi = mean(.data$.evpi)
     )
 }
 
@@ -71,9 +71,9 @@ export_psa <- function(x) {
       key_col = ".key",
       value_col = ".value",
       gather_cols = c(".cost", ".effect")) %>% 
-    dplyr::mutate_(
-      .var_name = ~ paste(.key, .strategy_names, sep = "_")) %>% 
-    dplyr::select_(~ - .key, ~ - .strategy_names) %>% 
+    dplyr::mutate(
+      .var_name = paste(.data$.key, .data$.strategy_names, sep = "_")) %>% 
+    dplyr::select(-.data$.key, -.data$.strategy_names) %>% 
     reshape_wide(key_col = ".var_name", value_col = ".value")
   
   list(
